;; Generated package description from taxy-magit-section.el  -*- no-byte-compile: t -*-
(define-package "taxy-magit-section" "0.9.1" "View Taxy structs in a Magit Section buffer" '((emacs "26.3") (magit-section "3.2.1")) :commit "62624c32d7f58bfa4acc89becc7cc8427d546aab" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("lisp") :url "https://github.com/alphapapa/taxy.el")
